@@ -20,26 +20,48 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <endian.h>
 #include <sys/ioctl.h>
 #include <alsa/asoundlib.h>
 #include <sound/hdsp.h>
 
-#include "firmware/multiface_firmware.dat"
-#include "firmware/digiface_firmware.dat"
-#include "firmware/multiface_firmware_rev11.dat"
-#include "firmware/digiface_firmware_rev11.dat"
+static u_int32_t code[24413];
+
+int read_bin_file(u_int32_t *array, const char *filename)
+{
+	FILE *out;
+
+	if ((out = fopen(filename, "r")) == NULL) {
+		fprintf(stderr, "Unable to open file '%s' for reading\n", filename);
+		return -1;
+	}
+	if (fread(array, 4, 24413, out) != 24413) {
+		fclose(out);
+		return -1;
+	}
+	fclose(out);
+#if __BYTE_ORDER == __BIG_ENDIAN
+	{
+		unsigned int idx;
+		for (idx = 0; idx < 24413; idx++)
+			array[idx] = ((array[idx] & 0x000000ff) << 16) |
+				     ((array[idx] & 0x0000ff00) << 8)  |
+				     ((array[idx] & 0x00ff0000) >> 8)  |
+				     ((array[idx] & 0xff000000) >> 16);
+	}
+#endif
+	return 0;
+}
 
 void upload_firmware(int card)
 {
-    int err, i;
+    int err;
     snd_hwdep_t *hw;
     snd_hwdep_info_t *info;
     char card_name[6];
     hdsp_version_t version;
-    unsigned long *fw;
     
     hdsp_firmware_t firmware;
-    hdsp_config_info_t config_info;
     
     snd_hwdep_info_alloca(&info);
     snprintf(card_name, 6, "hw:%i", card);
@@ -56,20 +78,21 @@ void upload_firmware(int card)
 	snd_hwdep_close(hw);
 	return;
     }
-    
+
+    firmware.firmware_data = (unsigned long *)code;
     switch (version.io_type) {
     case Multiface:
 	if (version.firmware_rev == 0xa) {
-	    fw = multiface_firmware;
+	    err = read_bin_file(code, DATAPATH "/multiface_firmware.bin");
 	} else {
-	    fw = multiface_firmware_rev11;
+	    err = read_bin_file(code, DATAPATH "/multiface_firmware_rev11.bin");
 	}
 	break;
     case Digiface:
 	if (version.firmware_rev == 0xa) {
-	    fw = digiface_firmware;
+	    err = read_bin_file(code, DATAPATH "/digiface_firmware.bin");
 	} else {
-	    fw = digiface_firmware_rev11;
+	    err = read_bin_file(code, DATAPATH "/digiface_firmware_rev11.bin");
 	}
 	break;
     default:
@@ -77,10 +100,8 @@ void upload_firmware(int card)
 	snd_hwdep_close(hw);
 	return;
     }	
-    
-    for (i = 0; i < 24413; ++i) {
-	firmware.firmware_data[i] = fw[i];
-    }
+    if (err < 0)
+    	return;
     
     if ((err = snd_hwdep_ioctl(hw, SNDRV_HDSP_IOCTL_UPLOAD_FIRMWARE, &firmware)) < 0) {
 	fprintf(stderr, "Hwdep ioctl error on card %s : %s.\n", card_name, snd_strerror(err));
@@ -97,12 +118,11 @@ void upload_firmware(int card)
 
 int main(int argc, char **argv)
 {
-    char **name;
+    char *name;
     int card;
 
     snd_ctl_card_info_t *info;
     snd_pcm_info_t *pcminfo;
-    int cards = 0;
     
     snd_ctl_card_info_alloca(&info);
     snd_pcm_info_alloca(&pcminfo);    
@@ -113,13 +133,12 @@ int main(int argc, char **argv)
 	if (card < 0) {
 	    break;
 	} else {
-	    snd_card_get_longname(card, name);
-	    printf("Card %d : %s\n", card, *name);
-	    if (!strncmp(*name, "RME Hammerfall DSP", 18)) {
+	    snd_card_get_longname(card, &name);
+	    printf("Card %d : %s\n", card, name);
+	    if (!strncmp(name, "RME Hammerfall DSP", 18)) {
 		upload_firmware(card);
 	    } 
 	}
     }
     return 0;    
 }
-
